@@ -52,8 +52,9 @@
 #include "ctkglx.h"
 #include "ctkmultisample.h"
 #include "ctkthermal.h"
+#include "ctkpowermizer.h"
 #include "ctkclocks.h"
-#include "ctkvcsc.h"
+#include "ctkvcs.h"
 #include "ctkpowersavings.h"
 
 #include "ctkdisplaydevice-crt.h"
@@ -233,9 +234,9 @@ static void help_button_toggled(GtkToggleButton *button, gpointer user_data)
     if (enabled) {
         if (ctk_window->ctk_help == NULL) {
             ctk_window->ctk_help = ctk_help_new(GTK_WIDGET(button),
-                    ctk_window->help_tag_table);
+                                                ctk_window->help_tag_table);
             ctk_help_set_page(CTK_HELP(ctk_window->ctk_help),
-                    ctk_window->help_text_buffer);
+                              ctk_window->help_text_buffer);
         }
         gtk_widget_show_all(ctk_window->ctk_help);
     } else {
@@ -371,8 +372,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                           gint num_screen_handles,
                           NvCtrlAttributeHandle **gpu_handles,
                           gint num_gpu_handles,
-                          NvCtrlAttributeHandle **vcsc_handles,
-                          gint num_vcsc_handles,
+                          NvCtrlAttributeHandle **vcs_handles,
+                          gint num_vcs_handles,
                           ParsedAttribute *p, ConfigProperties *conf)
 {
     GObject *object;
@@ -808,7 +809,16 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
             add_page(child, help, ctk_window, &iter, NULL, "Thermal Monitor",
                      NULL, ctk_thermal_start_timer, ctk_thermal_stop_timer);
         }
-        
+
+        /* Powermizer information */
+        child = ctk_powermizer_new(gpu_handle, ctk_config);
+        if (child) {
+            help = ctk_powermizer_create_help(tag_table, CTK_POWERMIZER(child));
+            add_page(child, help, ctk_window, &iter, NULL, "PowerMizer",
+                     NULL, ctk_powermizer_start_timer, 
+                     ctk_powermizer_stop_timer);
+        }
+ 
         /* clocks (GPU overclocking) */
 
         child = ctk_clocks_new(gpu_handle, ctk_config, ctk_event);
@@ -835,50 +845,50 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                             tag_table, data);
     }
 
-    /* add the per-vcsc (e.g. Quadro Plex) entries into the tree model */
+    /* add the per-vcs (e.g. Quadro Plex) entries into the tree model */
 
-    for (i = 0; i < num_vcsc_handles; i++) {
+    for (i = 0; i < num_vcs_handles; i++) {
         
         GtkTreeIter iter;
-        gchar *vcsc_product_name;
-        gchar *vcsc_name;
+        gchar *vcs_product_name;
+        gchar *vcs_name;
         GtkWidget *child;
         ReturnStatus ret;
-        NvCtrlAttributeHandle *vcsc_handle = vcsc_handles[i];
+        NvCtrlAttributeHandle *vcs_handle = vcs_handles[i];
 
-        if (!vcsc_handle) continue;
+        if (!vcs_handle) continue;
 
-        /* create the vcsc entry name */
+        /* create the vcs entry name */
 
-        ret = NvCtrlGetStringDisplayAttribute(vcsc_handle, 0,
+        ret = NvCtrlGetStringDisplayAttribute(vcs_handle, 0,
                                               NV_CTRL_STRING_VCSC_PRODUCT_NAME,
-                                              &vcsc_product_name);
-        if (ret == NvCtrlSuccess && vcsc_product_name) {
-            vcsc_name = g_strdup_printf("VCSC %d - (%s)",
-                                        NvCtrlGetTargetId(vcsc_handle),
-                                        vcsc_product_name);
+                                              &vcs_product_name);
+        if (ret == NvCtrlSuccess && vcs_product_name) {
+            vcs_name = g_strdup_printf("VCS %d - (%s)",
+                                        NvCtrlGetTargetId(vcs_handle),
+                                        vcs_product_name);
         } else {
-            vcsc_name =  g_strdup_printf("VCSC %d - (Unknown)",
-                                        NvCtrlGetTargetId(vcsc_handle));
+            vcs_name =  g_strdup_printf("VCS %d - (Unknown)",
+                                        NvCtrlGetTargetId(vcs_handle));
         }
-        if (!vcsc_name) continue;
+        if (!vcs_name) continue;
         
         /* create the object for receiving NV-CONTROL events */
         
-        ctk_event = CTK_EVENT(ctk_event_new(vcsc_handle));
+        ctk_event = CTK_EVENT(ctk_event_new(vcs_handle));
         
-        /* create the vcsc entry */
+        /* create the vcs entry */
 
         gtk_tree_store_append(ctk_window->tree_store, &iter, NULL);
         gtk_tree_store_set(ctk_window->tree_store, &iter,
-                           CTK_WINDOW_LABEL_COLUMN, vcsc_name, -1);
-        child = ctk_vcsc_new(vcsc_handle, ctk_config);
+                           CTK_WINDOW_LABEL_COLUMN, vcs_name, -1);
+        child = ctk_vcs_new(vcs_handle, ctk_config);
         gtk_object_ref(GTK_OBJECT(child));
         gtk_tree_store_set(ctk_window->tree_store, &iter,
                            CTK_WINDOW_WIDGET_COLUMN, child, -1);
         gtk_tree_store_set(ctk_window->tree_store, &iter,
                            CTK_WINDOW_HELP_COLUMN, 
-                           ctk_gpu_create_help(tag_table), -1);
+                           ctk_vcs_create_help(tag_table, CTK_VCS(child)), -1);
         gtk_tree_store_set(ctk_window->tree_store, &iter,
                            CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
                            NULL, -1);
@@ -1045,6 +1055,12 @@ static GtkWidget *create_quit_dialog(CtkWindow *ctk_window)
     gtk_container_add(GTK_CONTAINER(alignment), label);
     gtk_box_pack_start(GTK_BOX(hbox), alignment, FALSE, FALSE, 0);
 
+    /* Prevent the dialog from being deleted when closed */
+
+    g_signal_connect(G_OBJECT(dialog), "delete-event",
+                     G_CALLBACK(gtk_widget_hide_on_delete),
+                     (gpointer) dialog);
+
     return dialog;
 
 } /* create_quit_dialog() */
